"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createServer = exports.routerForApiSpec = exports.routeHandler = exports.middlewareFn = void 0;
const express_1 = __importDefault(require("express"));
const io_ts_http_1 = require("@api-ts/io-ts-http");
const typed_express_router_1 = require("@api-ts/typed-express-router");
const request_1 = require("./request");
const response_1 = require("./response");
var middleware_1 = require("./middleware");
Object.defineProperty(exports, "middlewareFn", { enumerable: true, get: function () { return middleware_1.middlewareFn; } });
var request_2 = require("./request");
Object.defineProperty(exports, "routeHandler", { enumerable: true, get: function () { return request_2.routeHandler; } });
function routerForApiSpec({ spec, routeHandlers, encoder = response_1.defaultResponseEncoder, }) {
    const router = (0, typed_express_router_1.createRouter)(spec, {
        onDecodeError: request_1.onDecodeError,
        onEncodeError: request_1.onEncodeError,
    });
    for (const apiName of Object.keys(spec)) {
        const resource = spec[apiName];
        for (const method of Object.keys(resource)) {
            if (!io_ts_http_1.Method.is(method)) {
                continue;
            }
            const httpRoute = resource[method];
            const routeHandler = routeHandlers[apiName][method];
            const expressRouteHandler = (0, request_1.handleRequest)(apiName, httpRoute, routeHandler, encoder);
            router[method](apiName, [expressRouteHandler]);
        }
    }
    return router;
}
exports.routerForApiSpec = routerForApiSpec;
const createServer = (spec, configureExpressApplication) => {
    const app = (0, express_1.default)();
    const routeHandlers = configureExpressApplication(app);
    const router = routerForApiSpec({ spec, routeHandlers });
    app.use(router);
    return app;
};
exports.createServer = createServer;
//# sourceMappingURL=index.js.map