import { ApiSpec, HttpRoute, RequestType, ResponseType } from '@api-ts/io-ts-http';
import { OnDecodeErrorFn, OnEncodeErrorFn, TypedRequestHandler } from '@api-ts/typed-express-router';
import { MiddlewareBrand, MiddlewareChain, MiddlewareChainOutput } from './middleware';
import type { KeyedResponseType, ResponseEncoder } from './response';
export declare type ServiceFunction<R extends HttpRoute, Input = RequestType<R>> = ((input: Input) => ResponseType<R> | Promise<ResponseType<R>>) | ((input: Input) => KeyedResponseType<R> | Promise<KeyedResponseType<R>>);
export declare type RouteHandler<R extends HttpRoute> = ServiceFunction<R> | {
    middleware: MiddlewareChain;
    handler: ServiceFunction<R, MiddlewareChainOutput<RequestType<R>, MiddlewareChain>>;
} | {
    middleware: MiddlewareChain;
    handler: ServiceFunction<R>;
    [MiddlewareBrand]: true;
};
export declare function routeHandler<R extends HttpRoute>({ handler, }: {
    handler: ServiceFunction<R>;
}): RouteHandler<R>;
export declare function routeHandler<R extends HttpRoute, Chain extends MiddlewareChain>({ middleware, handler, }: {
    middleware: Chain;
    handler: ServiceFunction<R, MiddlewareChainOutput<RequestType<R>, Chain>>;
}): RouteHandler<R>;
export declare const getServiceFunction: <R extends HttpRoute<"get" | "post" | "put" | "delete" | "patch">>(routeHandler: RouteHandler<R>) => ServiceFunction<R, RequestType<R>>;
export declare const getMiddleware: <R extends HttpRoute<"get" | "post" | "put" | "delete" | "patch">>(routeHandler: RouteHandler<R>) => MiddlewareChain;
export declare const onDecodeError: OnDecodeErrorFn;
export declare const onEncodeError: OnEncodeErrorFn;
export declare const handleRequest: (apiName: string, httpRoute: HttpRoute, handler: RouteHandler<HttpRoute>, responseEncoder: ResponseEncoder) => TypedRequestHandler<ApiSpec>;
//# sourceMappingURL=request.d.ts.map