"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultResponseEncoder = void 0;
const io_ts_http_1 = require("@api-ts/io-ts-http");
const defaultResponseEncoder = (route, serviceFnResponse) => (_req, res) => {
    const { type, payload } = serviceFnResponse;
    const status = typeof type === 'number' ? type : io_ts_http_1.KeyToHttpStatus[type];
    if (status === undefined) {
        console.warn(`Unknown status code ${status} returned`);
        res.status(500).end();
        return;
    }
    const responseCodec = route.response[status];
    try {
        res.status(status).json(responseCodec.encode(payload)).end();
    }
    catch (err) {
        console.warn(`Unable to encode route's return value, did you return the expected type?: ${err}`);
        res.status(500).end();
    }
};
exports.defaultResponseEncoder = defaultResponseEncoder;
//# sourceMappingURL=response.js.map